==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/ta-IN/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'This user can login',
    'activated_disabled_help_text' => 'You cannot edit activation status for your own account.',
    'assets_user'       => 'பெயரிடப்பட்ட சொத்துகள்: பெயர்',
    'bulk_update_warn'	=> 'User_count பயனர்களின் பண்புகளை நீங்கள் திருத்த வேண்டும். இந்த படிவத்தைப் பயன்படுத்தி உங்கள் சொந்த பயனர் பண்புகளை நீங்கள் மாற்ற முடியாது என்பதை நினைவில் கொள்ளவும், உங்கள் தனிப்பட்ட பயனருக்கு தனித்தனியாக திருத்தவும் வேண்டும்.',
    'bulk_update_help'	=> 'பல முறை பயனர்களைப் புதுப்பிக்க இந்த படிவம் உங்களை அனுமதிக்கிறது. நீங்கள் மாற்ற வேண்டிய துறைகள் மட்டுமே நிரப்பவும். காலியாக உள்ள எந்த புலமும் மாறாமல் இருக்கும்.',
    'current_assets'    => 'இந்த பயனருக்கு தற்போது சொத்துகள் சரிபார்க்கப்பட்டன',
    'clone'             => 'குளோன் பயனர்',
    'contact_user'      => 'தொடர்பு: பெயர்',
    'edit'              => 'பயனர் திருத்து',
    'filetype_info'     => 'அனுமதிக்கப்பட்ட கோப்புரிமைகள் png, gif, jpg, jpeg, doc, docx, pdf, txt, zip மற்றும் rar ஆகியவை.',
    'history_user'      => 'வரலாறு: பெயர்',
    'info'				=> 'தகவல்',
    'restore_user'		=> 'அவற்றை மீட்டெடுக்க இங்கு கிளிக் செய்க.',
    'last_login'        => 'கடைசி தேதி',
    'ldap_config_text'  => 'LDAP உள்ளமைவு அமைப்புகள் நிர்வாகம்> அமைப்புகள். இறக்குமதி செய்யப்பட்ட அனைத்து பயனர்களுக்கும் (விரும்பினால்) தேர்ந்தெடுக்கப்பட்ட இடம் அமைக்கப்படும்.',
    'print_assigned'    => 'ஒப்படைக்கப்பட்ட அனைத்தையும் அச்சிடு',
    'email_assigned'    => 'Email List of All Assigned',
    'user_notified'     => 'User has been emailed a list of their currently assigned items.',
    'auto_assign_label' => 'Include this user when auto-assigning eligible licenses',
    'auto_assign_help'  => 'Skip this user in auto assignment of licenses',
    'software_user'     => 'மென்பொருள் சரிபார்க்கப்பட்டது: பெயர்',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'பயனர் காண்க: பெயர்',
    'usercsv'           => 'CSV கோப்பு',
    'two_factor_admin_optin_help' => 'உங்கள் தற்போதைய நிர்வாக அமைப்புகள் இரண்டு காரணி அங்கீகரிப்பின் தேர்ந்தெடுக்கப்பட்ட செயல்பாட்டை அனுமதிக்கின்றன.',
    'two_factor_enrolled' => '2FA சாதனம் பதிவுசெய்யப்பட்டது',
    'two_factor_active'   => '2FA செயலில்',
    'user_deactivated'  => 'User cannot login',
    'user_activated'  => 'User can login',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion_information' => 'You are about to checkin ALL items from the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_assets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
    'remote_label'   => 'This is a remote user',
    'remote'   => 'Remote',
    'remote_help' => 'This can be useful if you need to filter by remote users who never or rarely come into your physical locations.',
    'not_remote_label' => 'This is not a remote user',
    'vip_label' => 'VIP user',
    'vip_help' => 'This can be helpful to mark important people in your org if you would like to handle them in special ways.',
    'create_user' => 'Create a user',
    'create_user_page_explanation' => 'This is the account information you will use to access the site for the first time.',
    'email_credentials' => 'Email credentials',
    'email_credentials_text' => 'Email my credentials to the email address above',
    'next_save_user' => 'Next: Save User',
    'all_assigned_list_generation' => 'Generated on:',
    'email_user_creds_on_create' => 'Email this user their credentials?',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/ta-IN/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'This user can login',
    'activated_disabled_help_text' => 'You cannot edit activation status for your own account.',
    'assets_user'       => 'பெயரிடப்பட்ட சொத்துகள்: பெயர்',
    'bulk_update_warn'	=> 'User_count பயனர்களின் பண்புகளை நீங்கள் திருத்த வேண்டும். இந்த படிவத்தைப் பயன்படுத்தி உங்கள் சொந்த பயனர் பண்புகளை நீங்கள் மாற்ற முடியாது என்பதை நினைவில் கொள்ளவும், உங்கள் தனிப்பட்ட பயனருக்கு தனித்தனியாக திருத்தவும் வேண்டும்.',
    'bulk_update_help'	=> 'பல முறை பயனர்களைப் புதுப்பிக்க இந்த படிவம் உங்களை அனுமதிக்கிறது. நீங்கள் மாற்ற வேண்டிய துறைகள் மட்டுமே நிரப்பவும். காலியாக உள்ள எந்த புலமும் மாறாமல் இருக்கும்.',
    'current_assets'    => 'இந்த பயனருக்கு தற்போது சொத்துகள் சரிபார்க்கப்பட்டன',
    'clone'             => 'குளோன் பயனர்',
    'contact_user'      => 'தொடர்பு: பெயர்',
    'edit'              => 'பயனர் திருத்து',
    'filetype_info'     => 'அனுமதிக்கப்பட்ட கோப்புரிமைகள் png, gif, jpg, jpeg, doc, docx, pdf, txt, zip மற்றும் rar ஆகியவை.',
    'history_user'      => 'வரலாறு: பெயர்',
    'info'				=> 'தகவல்',
    'restore_user'		=> 'அவற்றை மீட்டெடுக்க இங்கு கிளிக் செய்க.',
    'last_login'        => 'கடைசி தேதி',
    'ldap_config_text'  => 'LDAP உள்ளமைவு அமைப்புகள் நிர்வாகம்> அமைப்புகள். இறக்குமதி செய்யப்பட்ட அனைத்து பயனர்களுக்கும் (விரும்பினால்) தேர்ந்தெடுக்கப்பட்ட இடம் அமைக்கப்படும்.',
    'print_assigned'    => 'ஒப்படைக்கப்பட்ட அனைத்தையும் அச்சிடு',
    'email_assigned'    => 'Email List of All Assigned',
    'user_notified'     => 'User has been emailed a list of their currently assigned items.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Include this user when auto-assigning eligible licenses',
    'auto_assign_help'  => 'Skip this user in auto assignment of licenses',
    'software_user'     => 'மென்பொருள் சரிபார்க்கப்பட்டது: பெயர்',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'பயனர் காண்க: பெயர்',
    'usercsv'           => 'CSV கோப்பு',
    'two_factor_admin_optin_help' => 'உங்கள் தற்போதைய நிர்வாக அமைப்புகள் இரண்டு காரணி அங்கீகரிப்பின் தேர்ந்தெடுக்கப்பட்ட செயல்பாட்டை அனுமதிக்கின்றன.',
    'two_factor_enrolled' => '2FA சாதனம் பதிவுசெய்யப்பட்டது',
    'two_factor_active'   => '2FA செயலில்',
    'user_deactivated'  => 'User cannot login',
    'user_activated'  => 'User can login',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion_information' => 'You are about to checkin ALL items from the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_assets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
    'remote_label'   => 'This is a remote user',
    'remote'   => 'Remote',
    'remote_help' => 'This can be useful if you need to filter by remote users who never or rarely come into your physical locations.',
    'not_remote_label' => 'This is not a remote user',
    'vip_label' => 'VIP user',
    'vip_help' => 'This can be helpful to mark important people in your org if you would like to handle them in special ways.',
    'create_user' => 'Create a user',
    'create_user_page_explanation' => 'This is the account information you will use to access the site for the first time.',
    'email_credentials' => 'Email credentials',
    'email_credentials_text' => 'Email my credentials to the email address above',
    'next_save_user' => 'Next: Save User',
    'all_assigned_list_generation' => 'Generated on:',
    'email_user_creds_on_create' => 'Email this user their credentials?',
];
